diff --git a/.github/workflows/bsd.yml b/.github/workflows/bsd.yml
index 0b21a8a..bd11d5e 100644
--- a/.github/workflows/bsd.yml
+++ b/.github/workflows/bsd.yml
@@ -122,7 +122,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/local/include -Wall"
export LDFLAGS="-L/usr/local/lib"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -167,7 +167,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/pkg/include -Wall"
export LDFLAGS="-L/usr/pkg/lib"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -222,7 +222,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/local/include -Wall"
export LDFLAGS="-L/usr/local/lib"
- ./build-on.sh '${{ env.package }}' '' 'gmake' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'gmake' 'LIBTOOLFLAGS=--test' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
diff --git a/.github/workflows/linux.yml b/.github/workflows/linux.yml
index 3caf288..4649386 100644
--- a/.github/workflows/linux.yml
+++ b/.github/workflows/linux.yml
@@ -112,7 +112,7 @@ jobs:
- run: |
pwd
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -155,7 +155,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -200,7 +200,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -241,7 +241,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
diff --git a/.github/workflows/macos.yml b/.github/workflows/macos.yml
index 5335e49..19e7fbe 100644
--- a/.github/workflows/macos.yml
+++ b/.github/workflows/macos.yml
@@ -127,7 +127,7 @@ jobs:
export M4=m4
pwd
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
diff --git a/.github/workflows/many-platforms.yml b/.github/workflows/many-platforms.yml
index 1f232e3..b277e0f 100644
--- a/.github/workflows/many-platforms.yml
+++ b/.github/workflows/many-platforms.yml
@@ -114,7 +114,7 @@ jobs:
- run: |
pwd
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -159,7 +159,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -206,7 +206,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -249,7 +249,7 @@ jobs:
cd /work
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -299,7 +299,7 @@ jobs:
export M4=m4
pwd
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -347,7 +347,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/local/include -Wall"
export LDFLAGS="-L/usr/local/lib"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -394,7 +394,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/pkg/include -Wall"
export LDFLAGS="-L/usr/pkg/lib"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -451,7 +451,7 @@ jobs:
ls -l
export CPPFLAGS="-I/usr/local/include -Wall"
export LDFLAGS="-L/usr/local/lib"
- ./build-on.sh '${{ env.package }}' '' 'gmake' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'gmake' 'LIBTOOLFLAGS=--test' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -504,7 +504,7 @@ jobs:
export CPPFLAGS="-Wall"
export CC="gcc -m64"
export CXX="g++ -m64"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -552,7 +552,7 @@ jobs:
pwd
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'gmake' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'gmake' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -619,7 +619,7 @@ jobs:
- name: Build in Cygwin
run: |
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -685,7 +685,7 @@ jobs:
PATH=/usr/${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32/sys-root/mingw/bin:$PATH
export CPPFLAGS="-Wall"
export CC=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32-gcc
- ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -788,7 +788,7 @@ jobs:
export STRIP=":"
export AR="`pwd`/ar-lib lib"
export RANLIB=":"
- ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -831,7 +831,7 @@ jobs:
export LDFLAGS="-fsanitize=address,undefined,signed-integer-overflow,shift,integer-divide-by-zero"
export CFLAGS="-O0 -fno-omit-frame-pointer -ggdb"
export ASAN_OPTIONS="detect_leaks=0 abort_on_error=1 allocator_may_return_null=1"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
@@ -878,7 +878,7 @@ jobs:
export CPPFLAGS="-Wall"
export CC=clang
export CXX=clang++
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
# https://github.com/actions/upload-artifact?tab=readme-ov-file#usage
- if: ${{ always() }}
diff --git a/.github/workflows/solaris.yml b/.github/workflows/solaris.yml
index 6d97f18..90effe7 100644
--- a/.github/workflows/solaris.yml
+++ b/.github/workflows/solaris.yml
@@ -127,7 +127,7 @@ jobs:
export CPPFLAGS="-Wall"
export CC="gcc -m64"
export CXX="g++ -m64"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -173,7 +173,7 @@ jobs:
pwd
ls -l
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'gmake' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'gmake' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
diff --git a/.github/workflows/windows.yml b/.github/workflows/windows.yml
index dc1c2ce..efdbb28 100644
--- a/.github/workflows/windows.yml
+++ b/.github/workflows/windows.yml
@@ -141,7 +141,7 @@ jobs:
- name: Build in Cygwin
run: |
export CPPFLAGS="-Wall"
- ./build-on.sh '${{ env.package }}' '' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
@@ -205,7 +205,7 @@ jobs:
PATH=/usr/${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32/sys-root/mingw/bin:$PATH
export CPPFLAGS="-Wall"
export CC=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32-gcc
- ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '${{ github.event.head_commit.message }}'
+ ./build-on.sh '${{ env.package }}' '--host=${{ matrix.bitness == 32 && 'i686' || 'x86_64' }}-w64-mingw32' 'make' '' '${{ github.event.head_commit.message }}'
- if: ${{ always() && !contains(github.event.head_commit.message, '[pre-release]') }}
run: tar czf ${{ env.package }}-build.tar.gz ${{ env.package }}-*/
# Doc: https://docs.github.com/en/actions/using-workflows/storing-workflow-data-as-artifacts
diff --git a/build-dev-tarball.sh b/build-dev-tarball.sh
index f917828..310dcab 100755
--- a/build-dev-tarball.sh
+++ b/build-dev-tarball.sh
@@ -39,7 +39,7 @@ git clone --depth 2 -b "$branch" https://git.savannah.gnu.org/git/"$package".git
git clone --depth 1 https://git.savannah.gnu.org/git/gnulib.git
# Apply patches.
-(cd "$package" && patch -p1 < ../patches/0001-libtool.m4-Remove-OpenBSD-finish_cmds.patch)
+(cd "$package" && patch -p1 < ../patches/0001-libtool-Fix-local-testing-of-shared-libraries-on-Ope.patch)
export GNULIB_SRCDIR=`pwd`/gnulib
cd "$package"
diff --git a/patches/0001-libtool-Fix-local-testing-of-shared-libraries-on-Ope.patch b/patches/0001-libtool-Fix-local-testing-of-shared-libraries-on-Ope.patch
new file mode 100644
index 0000000..3c569dd
--- /dev/null
+++ b/patches/0001-libtool-Fix-local-testing-of-shared-libraries-on-Ope.patch
@@ -0,0 +1,114 @@
+From 3996b1fddcaa543c8bf349314cac3ab4b07b4d1d Mon Sep 17 00:00:00 2001
+From: Ileana Dumitrescu
+Date: Thu, 7 Nov 2024 16:29:19 +0200
+Subject: [PATCH] libtool: Fix local testing of shared libraries on OpenBSD
+
+On OpenBSD 7.5, the shared library cache is updated with finish_cmds,
+which causes the test for 'Use local version' to fail. Simply, installed
+versions of shared libraries take precedence over those locally built.
+
+To ensure local versions of shared libraries can be tested properly and
+more easily, additional options have been added to libtool to skip
+executing finish_cmds, like 'ldconfig -m $libdir' in OpenBSD.
+
+* build-aux/ltmain.in: Add libtool options, '--test' and '--check'.
+* doc/libtool.texi: Document new options in libtool.
+* NEWS: Update for bug fix.
+---
+ NEWS | 5 +++++
+ build-aux/ltmain.in | 14 +++++++++++++-
+ doc/libtool.texi | 9 ++++++++-
+ 3 files changed, 26 insertions(+), 2 deletions(-)
+
+diff --git a/NEWS b/NEWS
+index 96b79902..28e4ecbc 100644
+--- a/NEWS
++++ b/NEWS
+@@ -2,6 +2,11 @@ NEWS - list of user-visible changes between releases of GNU Libtool
+
+ * Noteworthy changes in release ?.? (????-??-??) [?]
+
++** New features:
++
++ - New libtool command line flags, --test and --check, to skip executing
++ finish_cmds that would alter the shared library cache during testing.
++
+ ** Bug fixes:
+
+ - Fix incorrect use of workarounds designed for Darwin versions that
+diff --git a/build-aux/ltmain.in b/build-aux/ltmain.in
+index 83aaaf92..83f1ad4f 100644
+--- a/build-aux/ltmain.in
++++ b/build-aux/ltmain.in
+@@ -377,6 +377,7 @@ libtool_options_prep ()
+ opt_mode=
+ opt_preserve_dup_deps=false
+ opt_quiet=false
++ opt_testing=true
+
+ nonopt=
+ preserve_args=
+@@ -507,6 +508,11 @@ libtool_parse_options ()
+ func_append preserve_args " $_G_opt"
+ ;;
+
++ --test|--check)
++ opt_testing=false
++ func_append preserve_args " $_G_opt"
++ ;;
++
+ # An option not handled by this hook function:
+ *) set dummy "$_G_opt" ${1+"$@"} ; shift
+ _G_match_lt_parse_options=false
+@@ -2144,7 +2150,7 @@ func_mode_finish ()
+ fi
+ fi
+
+- if test -n "$finish_cmds$finish_eval" && test -n "$libdirs"; then
++ if test -n "$finish_cmds$finish_eval" && test -n "$libdirs" && $opt_testing; then
+ for libdir in $libdirs; do
+ if test -n "$finish_cmds"; then
+ # Do each command in the finish commands.
+@@ -2169,6 +2175,12 @@ func_mode_finish ()
+ for libdir in $libdirs; do
+ $ECHO " $libdir"
+ done
++ if test "false" = "$opt_testing"; then
++ echo
++ echo "NOTE: finish_cmds were not executed during testing, so you must"
++ echo "manually run ldconfig to add a given test directory, LIBDIR, to"
++ echo "the search path for generated executables."
++ fi
+ echo
+ echo "If you ever happen to want to link against installed libraries"
+ echo "in a given directory, LIBDIR, you must either use libtool, and"
+diff --git a/doc/libtool.texi b/doc/libtool.texi
+index 803c90aa..484077ff 100644
+--- a/doc/libtool.texi
++++ b/doc/libtool.texi
+@@ -1272,6 +1272,12 @@ stripped or the link will fail. In cases where these duplications are
+ required, this option will preserve them, only stripping the libraries
+ that libtool knows it can safely.
+
++@item --test
++@itemx --check
++Do not execute finish_cmds (disabled by default). This option is for
++specifying that the testsuite is executing so that ldconfig will not alter
++the shared library cache, which is an issue observed on OpenBSD 7.5.
++
+ @item --quiet
+ @itemx --silent
+ Do not print out any progress or informational messages.
+@@ -6855,7 +6861,8 @@ shell does not support the shell option @code{nocaseglob}, making
+
+ @defvar finish_cmds
+ Commands to tell the dynamic linker how to find shared libraries in a
+-specific directory.
++specific directory. These commands can be disabled during testing local
++changes with @option{--test} or @option{--check}.
+ @end defvar
+
+ @defvar finish_eval
+--
+2.45.2
+
diff --git a/patches/0001-libtool.m4-Remove-OpenBSD-finish_cmds.patch b/patches/0001-libtool.m4-Remove-OpenBSD-finish_cmds.patch
deleted file mode 100644
index 50da1d0..0000000
--- a/patches/0001-libtool.m4-Remove-OpenBSD-finish_cmds.patch
+++ /dev/null
@@ -1,24 +0,0 @@
-From 7064eea526ecda1ff26016be003d4dbc24a72388 Mon Sep 17 00:00:00 2001
-From: Ileana Dumitrescu
-Date: Wed, 6 Nov 2024 21:35:36 +0200
-Subject: [PATCH] libtool.m4: Remove OpenBSD finish_cmds
-
----
- m4/libtool.m4 | 1 -
- 1 file changed, 1 deletion(-)
-
-diff --git a/m4/libtool.m4 b/m4/libtool.m4
-index 857e9c11..4ea3b140 100644
---- a/m4/libtool.m4
-+++ b/m4/libtool.m4
-@@ -3024,7 +3024,6 @@ openbsd*)
- need_version=yes
- fi
- library_names_spec='$libname$release$shared_ext$versuffix $libname$shared_ext$versuffix'
-- finish_cmds='PATH="\$PATH:/sbin" ldconfig -m $libdir'
- shlibpath_var=LD_LIBRARY_PATH
- shlibpath_overrides_runpath=yes
- ;;
---
-2.45.2
-
diff --git a/build-on.sh b/build-on.sh
index 3f55aea..6f7d561 100755
--- a/build-on.sh
+++ b/build-on.sh
@@ -16,12 +16,13 @@
# along with this program. If not, see .
# This script builds a tarball of the package on a single platform.
# Usage: build-on.sh PACKAGE CONFIGURE_OPTIONS MAKE COMMIT_MESSAGE
package="$1"
configure_options="$2"
make="$3"
-commit_message="$4"
+make_options="$4"
+commit_message="$5"
set -x
@@ -64,7 +65,7 @@ case "$commit_message" in
;;
*)
# Run the tests.
- $make check TESTSUITEFLAGS="--debug" > log3 2>&1; rc=$?; cat log3; test $rc = 0 || exit 1
+ $make check $make_options TESTSUITEFLAGS="--debug" > log3 2>&1; rc=$?; cat log3; test $rc = 0 || exit 1
;;
esac
@@ -16,12 +16,13 @@
# along with this program. If not, see .
# This script builds a tarball of the package on a single platform.
-# Usage: build-on.sh PACKAGE CONFIGURE_OPTIONS MAKE COMMIT_MESSAGE
+# Usage: build-on.sh PACKAGE CONFIGURE_OPTIONS MAKE MAKE_OPTIONS COMMIT_MESSAGE
package="$1"
configure_options="$2"